@@ -1,7 +1,7 @@
 # -*- coding: utf-8; -*-
 """
+Copyright (C) 2007-2009 Lincoln de Sousa <lincoln@minaslivre.org>
 Copyright (C) 2007 Gabriel Falcão <gabrielteratos@gmail.com>
-Copyright (C) 2007 Lincoln de Sousa <lincoln@archlinux-br.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -29,13 +29,11 @@ import subprocess
 import re
 import guake_globals
 
-OPEN_PROGRAMS = re.compile('((?:gnome|xdg)-open)')
-
 # Internationalization purposes.
 _ = gettext.gettext
 
-__all__ = ['_', 'ShowableError', 'test_dbus', 'test_gconf',
-           'pixmapfile', 'gladefile', 'hexify_color', 'open_uri',
+__all__ = ['_', 'ShowableError', 'test_gconf',
+           'pixmapfile', 'gladefile', 'hexify_color',
            'get_binaries_from_path']
 
 class ShowableError(Exception):
@@ -49,24 +47,18 @@ class ShowableError(Exception):
         if exit_code != -1:
             sys.exit(exit_code)
 
-def test_dbus(bus, interface):
-    obj = bus.get_object('org.freedesktop.DBus', '/org/freedesktop/DBus')
-    dbus_iface = dbus.Interface(obj, 'org.freedesktop.DBus')
-    avail = dbus_iface.ListNames()
-    return interface in avail
-
 def test_gconf():
     c = gconf.client_get_default()
     return c.dir_exists('/apps/guake')
 
 def pixmapfile(x):
-    f = os.path.join(guake_globals.image_dir, x)
+    f = os.path.join(guake_globals.IMAGE_DIR, x)
     if not os.path.exists(f):
         raise IOError('No such file or directory: %s' % f)
     return os.path.abspath(f)
 
 def gladefile(x):
-    f = os.path.join(guake_globals.glade_dir, x)
+    f = os.path.join(guake_globals.GLADE_DIR, x)
     if not os.path.exists(f):
         raise IOError('No such file or directory: %s' % f)
     return os.path.abspath(f)
@@ -83,15 +75,3 @@ def get_binaries_from_path(compiled_re):
                 if compiled_re.match(j):
                     ret.append(os.path.join(i, j))
     return ret
-
-def open_uri(uri):
-    binaries = get_binaries_from_path(OPEN_PROGRAMS)
-    if not binaries:
-        raise ShowableError(
-            _('Program not found in path'),
-            _('You don\'t have any available program '
-              'to interpret this uri. To solve this problem '
-              'just install gnome-open or xdg-open and try '
-              'again.'),
-            -1)
-    subprocess.Popen([binaries[0], uri])
