@@ -1,6 +1,6 @@
 # -*- coding: utf-8; -*-
 """
-Copyright (C) 2007,2008,2009 Lincoln de Sousa <lincoln@minaslivre.org>
+Copyright (C) 2007,2008,2009,2010 Lincoln de Sousa <lincoln@minaslivre.org>
 Copyright (C) 2007 Gabriel Falcão <gabrielteratos@gmail.com>
 
 This program is free software; you can redistribute it and/or
@@ -128,6 +128,7 @@ class GConfHandler(object):
         notify_add(KEY('/general/use_default_font'), self.default_font_toggled)
         notify_add(KEY('/style/font/style'), self.fstyle_changed)
         notify_add(KEY('/style/font/color'), self.fcolor_changed)
+        notify_add(KEY('/style/font/palette'), self.fpalette_changed)
         notify_add(KEY('/style/background/color'), self.bgcolor_changed)
         notify_add(KEY('/style/background/image'), self.bgimage_changed)
         notify_add(KEY('/style/background/transparency'),
@@ -258,6 +259,20 @@ class GConfHandler(object):
             i.set_color_foreground(fgcolor)
             i.set_color_bold(fgcolor)
 
+    def fpalette_changed(self, client, connection_id, entry, data):
+        """If the gconf var style/font/palette be changed, this method
+        will be called and will change the color scheme in all terminals
+        open.
+        """
+        fgcolor = gtk.gdk.color_parse(
+            client.get_string(KEY('/style/font/color')))
+        bgcolor = gtk.gdk.color_parse(
+            client.get_string(KEY('/style/background/color')))
+        palette = [gtk.gdk.color_parse(color) for color in 
+            entry.value.get_string().split(':')]
+        for i in self.guake.term_list:
+            i.set_colors(fgcolor, bgcolor, palette)
+
     def bgcolor_changed(self, client, connection_id, entry, data):
         """If the gconf var style/background/color be changed, this
         method will be called and will change the background color in
@@ -584,6 +599,16 @@ class Guake(SimpleGladeApp):
         self.get_widget('tab-menu').connect('hide', hide_context_menu)
         self.window.connect('focus-out-event', self.on_window_losefocus)
 
+        # Handling the delete-event of the main window to avoid
+        # problems when closing it.
+        def destroy(*args):
+            self.hide()
+            return True
+        self.window.connect('delete-event', destroy)
+
+        # Flag to completly disable losefocus hiding
+        self.disable_losefocus_hiding = False
+
         # this line is important to resize the main window and make it
         # smaller.
         self.window.set_geometry_hints(min_width=1, min_height=1)
@@ -659,9 +684,12 @@ class Guake(SimpleGladeApp):
         """Hides terminal main window when it loses the focus and if
         the window_losefocus gconf variable is True.
         """
+        if self.disable_losefocus_hiding or self.showing_context_menu:
+            return
+
         value = self.client.get_bool(KEY('/general/window_losefocus'))
         visible = window.get_property('visible')
-        if value and visible and not self.showing_context_menu:
+        if value and visible:
             self.losefocus_time = \
                 gtk.gdk.x11_get_server_time(self.window.window)
             self.hide()
@@ -837,6 +865,7 @@ class Guake(SimpleGladeApp):
         self.client.notify(KEY('/general/show_resizer'))
         self.client.notify(KEY('/style/font/style'))
         self.client.notify(KEY('/style/font/color'))
+        self.client.notify(KEY('/style/font/palette'))
         self.client.notify(KEY('/style/background/color'))
         self.client.notify(KEY('/style/background/image'))
         self.client.notify(KEY('/style/background/transparency'))
@@ -979,12 +1008,14 @@ class Guake(SimpleGladeApp):
         dialog.add_action_widget(entry, gtk.RESPONSE_ACCEPT)
         entry.reparent(vbox)
 
+        self.disable_losefocus_hiding = True
         response = dialog.run()
-        dialog.destroy()
+        self.disable_losefocus_hiding = False
 
         if response == gtk.RESPONSE_ACCEPT:
             self.selected_tab.set_label(entry.get_text())
 
+        dialog.destroy()
         self.set_terminal_focus()
 
     def on_close_activate(self, *args):
@@ -1049,8 +1080,41 @@ class Guake(SimpleGladeApp):
         if default_params:
             params.update(default_params)
 
+        # Environment variables are not actually parameters but they
+        # need to be set before calling terminal.fork_command()
+        # method. So I found this place good to do it.
+        self.update_proxy_vars()
         return params
 
+    def update_proxy_vars(self):
+        """This method updates http{s,}_proxy environment variables
+        with values found in gconf.
+        """
+        proxy = '/system/http_proxy/'
+        if self.client.get_bool(proxy + 'use_http_proxy'):
+            host = self.client.get_string(proxy + 'host')
+            port = self.client.get_int(proxy + 'port')
+            if self.client.get_bool(proxy + 'use_same_proxy'):
+                ssl_host = host
+                ssl_port = port
+            else:
+                ssl_host = self.client.get_string('/system/proxy/secure_host')
+                ssl_port = self.client.get_string('/system/proxy/secure_port')
+
+            if self.client.get_bool(proxy + 'use_authentication'):
+                auth_user = self.client.get_string(
+                    proxy + 'authentication_user')
+                auth_pass = self.client.get_string(
+                    proxy + 'authentication_password')
+                os.environ['http_proxy'] = 'http://%s:%s@%s:%d' % (
+                    auth_user, auth_pass, host, port)
+                os.environ['https_proxy'] = 'http://%s:%s@%s:%d' % (
+                    auth_user, auth_pass, ssl_host, ssl_port)
+            else:
+                os.environ['http_proxy'] = 'http://%s:%d' % (host, port)
+                os.environ['https_proxy'] = 'http://%s:%d' % (
+                    ssl_host, ssl_port)
+
     def add_tab(self, directory=None):
         """Adds a new tab to the terminal notebook.
         """
