@@ -26,9 +26,9 @@ __all__ = [
     ]
 
 NAME = 'guake'
-VERSION = '0.4.1'
-IMAGE_DIR = '../data/pixmaps'
-GLADE_DIR = '../data'
+VERSION = '0.4.2'
+IMAGE_DIR = '/home/lincoln/Local/share/pixmaps/' + NAME
+GLADE_DIR = '/home/lincoln/Local/share/' + NAME
 LOCALE_DIR = '/home/lincoln/Local/share/locale'
 
 # Gconf stuff. Yep, it is hardcoded =)
